#!/usr/bin/env Rscript

#### Loading packages #### 
library(DESeq2)
library(phyloseq) 
library(ape)
library(tidyverse)
library(vegan)

#### Loading data #### 
load("/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_final.RData")

#### Filtering samples ####
dysautonomia_mild <- subset_samples(dysautonomia_final, FD.severity %in% c("control", "mild"))
dysautonomia_moderate <- subset_samples(dysautonomia_final, FD.severity %in% c("control", "moderate"))
dysautonomia_severe <- subset_samples(dysautonomia_final, FD.severity %in% c("control", "severe"))
dysautonomia_mil_severe <- subset_samples(dysautonomia_final, FD.severity %in% c("mild", "severe"))

#### DESeq for Control vs Mild FD ####
deseq_dysautonomia_mild <- phyloseq_to_deseq2(dysautonomia_mild,~FD.severity)
DESEQ_mild <- DESeq(deseq_dysautonomia_mild)
res <- results(DESEQ_mild, tidy=TRUE)

# Volcano plot: effect size VS significance
ggplot(res) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))
control_mild_volcano_plot <- res %>%
  mutate(significant = padj<0.05 & abs(log2FoldChange)>1.5) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))
ggsave(filename = "Volcano_plot_control_mild.png"
       , control_mild_volcano_plot
       , height=4, width=5)

# Table of results
sigASVs <- res %>% 
  filter(padj<0.05 & abs(log2FoldChange)>1.5) %>%
  dplyr::rename(ASV=row)
View(sigASVs)

# There are no ASVs significantly different between the mild and control groups

#### DESeq for Control vs Moderate FD ####
deseq_dysautonomia_moderate <- phyloseq_to_deseq2(dysautonomia_moderate,~FD.severity)
DESEQ_moderate <- DESeq(deseq_dysautonomia_moderate)
res_2 <- results(DESEQ_moderate, tidy=TRUE)

# Volcano plot: effect size VS significance
ggplot(res_2) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))
control_moderate_volcano_plot <- res_2 %>%
  mutate(significant = padj<0.05 & abs(log2FoldChange)>1.5) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))
ggsave(filename = "Volcano_plot_control_moderate.png"
       , control_moderate_volcano_plot
       , height=4, width=5)

# Table of results
sigASVs_moderate <- res_2 %>% 
  filter(padj<0.05 & abs(log2FoldChange)>1.5) %>%
  dplyr::rename(ASV=row)
View(sigASVs_moderate)
# Significant ASVs
sigASVs_moderate_vec <- sigASVs_moderate %>%
  pull(ASV)

# There are 5 significantly different ASVs between the control and moderate groups: da47a7f676f9a37da03e64a99251fd78, 04e96f8e3e9a8aaea0cf71feba8b0e16, 12691e42e5f8f917a8ca55e38670afdd, 95fdd816723ca482a5caba10bea171c8, 17cddb82ce2f004cd99f8fb8e90daae2    

# Identifying the differentially abundant ASVs at the phylum level
moderate_FD_DESeq <- prune_taxa(sigASVs_moderate_vec,dysautonomia_moderate)
moderate_sigASVs <- tax_table(moderate_FD_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_moderate) %>%
  arrange(log2FoldChange) %>%
  mutate(Phylum = make.unique(Phylum)) %>%
  mutate(Phylum = factor(Phylum, levels=unique(Phylum)))
ggplot(moderate_sigASVs) +
  geom_bar(aes(x=Phylum, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Phylum, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE))

# Identifying the differentially abundant ASVs at the genus level
moderate_sigASVs <- tax_table(moderate_FD_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_moderate) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))
ggplot(moderate_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE))

# Identifying the differentially abundant ASVs at the species level
moderate_sigASVs <- tax_table(moderate_FD_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_moderate) %>%
  arrange(log2FoldChange) %>%
  mutate(Species = make.unique(Species)) %>%
  mutate(Species = factor(Species, levels=unique(Species)))
ggplot(moderate_sigASVs) +
  geom_bar(aes(x=Species, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Species, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) + theme(axis.text.x = element_text(angle = 90))

#### DESeq for Control vs Severe FD ####
deseq_dysautonomia_severe <- phyloseq_to_deseq2(dysautonomia_severe,~FD.severity) 
DESEQ_severe <- DESeq(deseq_dysautonomia_severe)
res_3 <- results(DESEQ_severe, tidy=TRUE)

# Volcano plot: effect size VS significance
ggplot(res_3) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))
control_severe_volocano <- res_3 %>%
  mutate(significant = padj<0.05 & abs(log2FoldChange)>1.5) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))
ggsave(filename = "Volcano_plot_control_severe.png"
       , control_severe_volocano
       , height=4, width=6)

# Table of results
sigASVs_severe <- res_3 %>% 
  filter(padj<0.05 & abs(log2FoldChange)>1.5) %>%
  dplyr::rename(ASV=row)
View(sigASVs_severe)
# Significant ASVs
sigASVs_severe_vec <- sigASVs_severe %>%
  pull(ASV)
# There are 10 significantly different ASVs between the control and severe group: a9b24370bdb02a8ee91855de7b8b2813, 672f8fd554c7fe3dc2d9d694370c7276, 95d6a2a0e7a344010b5fd670677848e1, da47a7f676f9a37da03e64a99251fd78, 2197e3c697e9c1427ae1c3277d3c71f9, 0d29a1eb24f264423251f3b2a92f7914, 3d2cd874a4eea35af603ca0c0c25c89f, 95fdd816723ca482a5caba10bea171c8, 17cddb82ce2f004cd99f8fb8e90daae2, 6f1cbae792de3e1162d3d7dffbe4bb20   

# Identifying the differentially abundant ASVs at the phylum level
severe_FD_DESeq <- prune_taxa(sigASVs_severe_vec,dysautonomia_severe)
severe_sigASVs <- tax_table(severe_FD_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_severe) %>%
  arrange(log2FoldChange) %>%
  mutate(Phylum = make.unique(Phylum)) %>%
  mutate(Phylum = factor(Phylum, levels=unique(Phylum)))
ggplot(severe_sigASVs) +
  geom_bar(aes(x=Phylum, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Phylum, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE))+ theme(axis.text.x = element_text(angle = 90))

# Identifying the differentially abundant ASVs at the genus level
severe_sigASVs <- tax_table(severe_FD_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_severe) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))
ggplot(severe_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE))+ theme(axis.text.x = element_text(angle = 90))

# Identifying the differentially abundant ASVs at the species level
severe_sigASVs <- tax_table(severe_FD_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_severe) %>%
  arrange(log2FoldChange) %>%
  mutate(Species = make.unique(Species)) %>%
  mutate(Species = factor(Species, levels=unique(Species)))
ggplot(severe_sigASVs) +
  geom_bar(aes(x=Species, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Species, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE))+ theme(axis.text.x = element_text(angle = 90))

#### Log fold change plot comparing the control and severe conditions at the genus level ####
# Combining p-values 
combine_pvalues = function(p){
  return(1-pchisq(-2*sum(log(p),na.rm=T),2*sum(!is.na(p))))}
#Running DESEQ on the phyloseq object
deseq_dysautonomia_severe <- phyloseq_to_deseq2(dysautonomia_severe,~FD.severity) 
DESEQ_severe <- DESeq(deseq_dysautonomia_severe)
res_3 <- results(DESEQ_severe, tidy=TRUE)
#Combining the results output with taxa information.
tax_cs_dysautonomia <- tax_table(dysautonomia_severe)
DEseq_results <- data.frame(cbind(res_3,tax_cs_dysautonomia)) 
cs_dysautonomia_DEseq_results <- DEseq_results[,-1]
view(cs_dysautonomia_DEseq_results)

# Filtering the deseq results at taxa and genus levels.
cs_dysautonomia_DEseq_results_genus_summary<-cs_dysautonomia_DEseq_results %>%
  group_by(Phylum,Class,Order,Family,Genus) %>%
  select(Phylum,Class,Order,Family,Genus,log2FoldChange,padj,baseMean,pvalue) %>%
  filter(padj<0.05) %>%
  summarise(mean_2_fold_change=mean(log2FoldChange),padj=combine_pvalues(padj),countmean = mean(baseMean),pvalue=combine_pvalues(pvalue)) %>%
  drop_na(mean_2_fold_change) 

# Reformating the Genus and Phylum names to remove "p__"
cs_dysautonomia_DEseq_results_genus_summary$Phylum = gsub("p__","",cs_dysautonomia_DEseq_results_genus_summary$Phylum) 
cs_dysautonomia_DEseq_results_genus_summary$Genus = gsub("g__","",cs_dysautonomia_DEseq_results_genus_summary$Genus) 

# Visualizing the results
cs_DEseqafterfiltergenus <- ggplot(cs_dysautonomia_DEseq_results_genus_summary,aes(x=reorder(Genus, -mean_2_fold_change),y=mean_2_fold_change,color = Phylum)) +
  geom_point(size=3) +
  theme_bw()+
  geom_hline(yintercept = 0) +
  theme(axis.text.x = element_text(angle = -90,hjust = 0,vjust = 0.5),
        text = element_text(face = "bold"),
        axis.text.x.bottom  = element_text(,angle = -45)) +
  labs(x="Genus",y="Log2 Fold Change",color= "Phylum")

ggsave(filename = "DESeq_control_severe.png"
       , cs_DEseqafterfiltergenus
       , height=6, width=8)

